@@ -2,17 +2,18 @@ use 5.008000;
 use strict;
 use warnings;
 
+use lib 't/tlib';
+
 use Test::More;
-use Test::RedisServer;
+use Test::RedisRunner;
 use AnyEvent;
 use version 0.77;
 
-####
 sub run_redis_instance {
   my %params = @_;
 
   my $redis_server = eval {
-    return Test::RedisServer->new(
+    return Test::RedisRunner->new(
       conf => \%params,
     );
   };
@@ -20,29 +21,16 @@ sub run_redis_instance {
     return;
   }
 
-  my $host;
-  my $port;
   my %conn_info = $redis_server->connect_info();
-  if ( defined $conn_info{server} ) {
-    ( $host, $port ) = split( ':', $conn_info{server} );
-  }
-  elsif ( defined $conn_info{sock} ) {
-    $host = 'unix/';
-    $port = $conn_info{sock};
-  }
-  else {
-    BAIL_OUT( "Can't obtain connection info for redis-server" );
-  }
 
   return {
     server   => $redis_server,
-    host     => $host,
-    port     => $port,
+    host     => $conn_info{host},
+    port     => $conn_info{port},
     password => $params{requirepass},
   };
 }
 
-####
 sub ev_loop {
   my $sub = shift;
 
@@ -62,7 +50,6 @@ sub ev_loop {
   return;
 }
 
-####
 sub get_redis_version {
   my $redis = shift;
 
